@@ -1,8 +1,9 @@
+//! Library to implement genetic algorithms
+
 pub mod gene;
 pub mod genetic_algorithm;
 pub mod selection;
 
 pub use gene::Gene;
 pub use genetic_algorithm::GeneticAlgorithm;
-pub use selection::Selection;
-pub use selection::SelectionAlgorithms;
\ No newline at end of file
+pub use selection::*;
\ No newline at end of file
